[Telepathy-commits] [telepathy-gabble/master] offer-accept-private-dbus-stream-tube-ibb: Status has been renamed to State

Guillaume Desmottes guillaume.desmottes at collabora.co.uk
Tue Jan 27 09:22:27 PST 2009


---
 .../offer-accept-private-dbus-stream-tube-ibb.py   |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/tests/twisted/tubes/offer-accept-private-dbus-stream-tube-ibb.py b/tests/twisted/tubes/offer-accept-private-dbus-stream-tube-ibb.py
index 9d814c2..511a52b 100644
--- a/tests/twisted/tubes/offer-accept-private-dbus-stream-tube-ibb.py
+++ b/tests/twisted/tubes/offer-accept-private-dbus-stream-tube-ibb.py
@@ -853,13 +853,13 @@ def test(q, bus, conn, stream):
     assert props[TARGET_HANDLE] == bob_handle
     assert props[TARGET_ID] == 'bob at localhost'
     assert props[DBUS_TUBE_SERVICE_NAME] == 'com.example.TestCase2'
     # FIXME: check if Status and Parameters are *not* in props
 
     tube_chan = bus.get_object(conn.bus_name, path)
     tube_chan_iface = dbus.Interface(tube_chan, CHANNEL)
     dbus_tube_iface = dbus.Interface(tube_chan, CHANNEL_TYPE_DBUS_TUBE)
 
-    status = tube_chan.Get(CHANNEL_IFACE_TUBE, 'Status', dbus_interface=PROPERTIES_IFACE)
+    status = tube_chan.Get(CHANNEL_IFACE_TUBE, 'State', dbus_interface=PROPERTIES_IFACE)
     assert status == TUBE_STATE_LOCAL_PENDING
 
     # accept the tube (new API)
@@ -853,13 +853,13 @@ def test(q, bus, conn, stream):
     assert props[TARGET_ID] == 'bob at localhost'
     assert props[DBUS_TUBE_SERVICE_NAME] == 'com.example.TestCase2'
-    # FIXME: check if Status and Parameters are *not* in props
+    # FIXME: check if State and Parameters are *not* in props
 
     tube_chan = bus.get_object(conn.bus_name, path)
-- 
1.5.6.5




More information about the telepathy-commits mailing list